diff --git a/README.md b/README.md
old mode 100644
new mode 100755
index 1ee455b..bc54012
--- a/README.md
+++ b/README.md
@@ -32,7 +32,7 @@ The people responsible for the ESE create a new list of keys by using the page *
### 5. Analyse the results of the evaluation questionnaires
-//TODO
+Just go to the *analysis.php* site to see the results.
### 6. Files
diff --git a/keyControlPanel.php b/keyControlPanel.php
old mode 100644
new mode 100755
diff --git a/keyTable.php b/keyTable.php
old mode 100644
new mode 100755
diff --git a/libs/chartLib.php b/libs/chartLib.php
old mode 100644
new mode 100755
diff --git a/libs/formLib.php b/libs/formLib.php
old mode 100644
new mode 100755
index 93f1198..c84a402
--- a/libs/formLib.php
+++ b/libs/formLib.php
@@ -1,9 +1,9 @@
\n";
echo "\n";
}
+
+ /**
+ * Echos a new division with a labelled text box and switching row styles.
+ *
+ * @param string $label The label that should be displayed for the dropdown menu.
+ * @param string $id The unique id that is used to identify the dropdownmenu.
+ * @param string $value The options that should be displayed within the dropdown menu.
+ *
+ */
+ function CreateDropDownMenu($label, $id, $value)
+ {
+ CreateRowHeader();
+ echo "
" . $label . "
\n"; + echo "
diff --git a/analysis.php b/analysis.php
old mode 100644
new mode 100755
diff --git a/css/bootstrap.css b/css/bootstrap.css
old mode 100644
new mode 100755
diff --git a/css/ese-logo.png b/css/ese-logo.png
old mode 100644
new mode 100755
diff --git a/css/print.css b/css/print.css
old mode 100644
new mode 100755
diff --git a/css/style.css b/css/style.css
old mode 100644
new mode 100755
diff --git a/index.php b/index.php
old mode 100644
new mode 100755
index 3761f61..9091f82
--- a/index.php
+++ b/index.php
@@ -17,8 +17,9 @@
$error = 0;
// Determines if a message box is shown, and what type of message box is shown
$keyState = "";
// load the questionnaire data
$questionnaire = ReadQuestionnaireFile(STUDENT_QUESTIONNAIRE);
+ $patrons = ReadPatronsFile(PATRONS);
// if the variable is set, the form has been posted to itself and can be validated
if (isset($_POST["submit"]))
{
@@ -69,11 +70,11 @@
Bitte versuch es später nocheinmal oder wende dich an einen der Verantwortlichen.");
+ CreateMessageBox(MSG_DANGER, "Achtung:", "Deine Evaluation konnte aufgrund eines internen Fehlers leider nicht erfolgreich bearbeitet werden.
Bitte versuch es später nocheinmal oder wende dich an einen der Verantwortlichen.");
else
CreateKeyMessageBox($keyState);
CreateQuestionnaireElement("code", $questionnaire, $_POST);
- CreateQuestionnaireElement("tutorName", $questionnaire, $_POST);
+ CreateQuestionnaireElement("tutorName", $questionnaire, $patrons);
CreateQuestionnaireElement("legend", $questionnaire, $_POST);
CreateAllQuestionElements($questionnaire, $_POST);
CreateQuestionnaireElement("comment", $questionnaire, $_POST);
@@ -17,8 +17,9 @@
// Determines if a message box is shown, and what type of message box is shown
$keyState = "";
- // load the questionnaire data
+ // load the questionnaire and patrons data
$questionnaire = ReadQuestionnaireFile(STUDENT_QUESTIONNAIRE);